==> jscommunicator-1.0.27.tgz: package/lib/basePush.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var base = require('./base');
var types = require('./types');
var exceptions = require('./exceptions');
var emptyValues = ['', null, {}, [], undefined];

var BasePush = function (_base$Base) {
    _inherits(BasePush, _base$Base);

    function BasePush(request, config, appName) {
        _classCallCheck(this, BasePush);

        var _this = _possibleConstructorReturn(this, (BasePush.__proto__ || Object.getPrototypeOf(BasePush)).call(this, request, config, appName));

        _this.push_relation_keys = ['app_version', 'last_active'];
        _this.push_relations = ['=', '>', '<', '>=', '<='];
        _this.comm_app_name = '';
        _this.mandatory_keys = ['service', 'reference_id', 'reference_type', 'data'];
        _this.queueName = '';
        _this.pushNotification = {};
        return _this;
    }

    _createClass(BasePush, [{
        key: 'isEmpty',
        value: function isEmpty(value) {
            if (emptyValues.indexOf(value) > -1) return true;
            return false;
        }
    }, {
        key: 'areArraysEqual',
        value: function areArraysEqual(arr1, arr2) {
            return arr1.sort().toString() == arr2.sort().toString();
        }
    }, {
        key: 'removeEmptyKeys',
        value: function removeEmptyKeys(pushDict) {
            var updated_dict = {};
            for (var key in pushDict) {
                var value = pushDict[key];
                if (this.isEmpty(value)) continue;else if (typeof value == "object") {
                    var updated_value = this.removeEmptyKeys(value);
                    if (this.isEmpty(updated_value)) continue;
                    updated_dict[key] = updated_value;
                } else {
                    updated_dict[key] = value;
                }
            }
            return updated_dict;
        }
    }, {
        key: 'sendPushNotification',
        value: function sendPushNotification() {
            var job_dict = this.pushNotification;
            job_dict = this.validate(job_dict);
            this.send(job_dict, this.queueName, 0);
        }
    }, {
        key: 'addHeaders',
        value: function addHeaders(input_object) {
            this.pushNotification.reference_id = input_object.reference_id;
            this.pushNotification.reference_type = input_object.reference_type;
            if ('is_silent' in input_object) this.pushNotification.is_silent = input_object.is_silent;
            if ('is_content_available' in input_object) this.pushNotification.is_content_available = input_object.is_content_available;
            if ('push_type' in input_object) this.pushNotification.push_type = input_object.push_type;
        }
    }, {
        key: 'addFilters',
        value: function addFilters(input_object) {
            if ('last_active' in input_object) this.pushNotification.last_active = input_object.last_active;
            if ('account_id' in input_object) this.pushNotification.account_id = input_object.account_id;
            if ('device_id' in input_object) this.pushNotification.device_id = input_object.device_id;
            if ('app_version' in input_object) this.pushNotification.app_version = input_object.app_version;
        }
    }, {
        key: 'addData',
        value: function addData(input_object) {
            if ('data' in input_object) Object.assign(this.pushNotification.data, input_object.data);
        }
    }, {
        key: 'preparePushBody',
        value: function preparePushBody(input_object) {
            this.addHeaders(input_object);
            this.addFilters(input_object);
            this.addData(input_object);
        }
    }, {
        key: 'validatePushType',
        value: function validatePushType(push_type) {
            throw new exceptions.PushNotImplementedException('Validate push type has not been implemented');
        }
    }, {
        key: 'validateFilters',
        value: function validateFilters(pushDict) {
            throw new exceptions.PushNotImplementedException('Validate filters has not been implemented');
        }
    }, {
        key: 'validatePushRelationKeys',
        value: function validatePushRelationKeys(pushDict) {
            for (var index = 0; index < this.push_relation_keys.length; index++) {
                var key = this.push_relation_keys[index];
                var value = pushDict[key] ? 'key' in pushDict : {};
                if (Object.keys(value).length !== 0) {
                    if (['value', 'relation'] !== Object.keys(value)) {
                        throw new exceptions.PushValidationException("Invalid keys in last active");
                    }
                    if (this.push_relations.indexOf(value['relation']) < 0) {
                        throw new exceptions.PushValidationException("Invalid relation in last active");
                    }
                }
            }
        }
    }, {
        key: 'validateMandatoryKeys',
        value: function validateMandatoryKeys(mandatory_keys, pushDict) {
            var missing_keys = Array.from(new Set(mandatory_keys) - new Set(Object.keys(pushDict)));
            if (missing_keys.length !== 0) throw new exceptions.PushValidationException("Missing Mandatory Keys {}".format(missing_keys));
            for (var index = 0; index < mandatory_keys.length; index++) {
                var key = mandatory_keys[index];
                if (emptyValues.indexOf(pushDict[key]) >= 0) throw new exceptions.PushValidationException("Key {} cannot be empty".format(key));
            }
        }
    }, {
        key: 'validateTypes',
        value: function validateTypes(pushDict) {
            var ptypes = new types.PushDataTypes();
            for (var key in ptypes.types) {
                var val = pushDict[key];
                if (val === undefined) {
                    continue;
                }
                if (emptyValues.indexOf(val) >= 0 || typeof val !== ptypes.types[key]) {
                    throw new exceptions.PushValidationException("Invalid Type for key " + key);
                }
            }
        }
    }, {
        key: 'validateAndroidData',
        value: function validateAndroidData(androidData) {
            if (emptyValues.indexOf(androidData) >= 0) throw new exceptions.PushValidationException("No Data in Android Payload");
        }
    }, {
        key: 'validateIosData',
        value: function validateIosData(iosData, isIosSilent, pushDict) {
            if (emptyValues.indexOf(iosData) >= 0) throw new exceptions.PushValidationException("No Data in Ios Payload");
            if (isIosSilent) {
                pushDict.is_content_available = true;
                if (!this.areArraysEqual(Object.keys(iosData), ['custom'])) {
                    throw new exceptions.PushValidationException("Silent Push can only have custom keys");
                }
            } else if (this.areArraysEqual(Object.keys(iosData), ['custom'])) {
                throw new exceptions.PushValidationException("Non Silent Push data cant be empty");
            }
        }
    }, {
        key: 'validateData',
        value: function validateData(pushDict) {
            if (pushDict.is_silent === undefined) throw new exceptions.PushValidationException("Is Silent value cannot be undefined");
            if ('android' === pushDict.app_name) this.validateAndroidData(pushDict.data);else if ('ios' === pushDict.app_name) this.validateIosData(pushDict.data, pushDict.is_silent, pushDict);
        }
    }, {
        key: 'validate',
        value: function validate(pushDict) {
            pushDict = this.removeEmptyKeys(pushDict);
            this.validateTypes(pushDict);
            this.validateMandatoryKeys(this.mandatory_keys, pushDict);
            this.validateFilters(pushDict);
            this.validateData(pushDict);
            this.validatePushType(pushDict.push_type);
            pushDict.app_name = this.comm_app_name;
            return pushDict;
        }
    }]);

    return BasePush;
}(base.Base);

module.exports = {
    BasePush: BasePush
};

==> jscommunicator-1.0.32.tgz: package/lib/basePush.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var base = require('./base');
var types = require('./types');
var exceptions = require('./exceptions');
var emptyValues = ['', null, {}, [], undefined];

var BasePush = function (_base$Base) {
    _inherits(BasePush, _base$Base);

    function BasePush(request, config, appName) {
        _classCallCheck(this, BasePush);

        var _this = _possibleConstructorReturn(this, (BasePush.__proto__ || Object.getPrototypeOf(BasePush)).call(this, request, config, appName));

        _this.push_relation_keys = ['app_version_code', 'app_version', 'last_active'];
        _this.push_relations = ['=', '>', '<', '>=', '<='];
        _this.comm_app_name = '';
        _this.mandatory_keys = ['service', 'reference_id', 'reference_type', 'data'];
        _this.queueName = '';
        _this.pushNotification = {};
        return _this;
    }

    _createClass(BasePush, [{
        key: 'isEmpty',
        value: function isEmpty(value) {
            if (emptyValues.indexOf(value) > -1) return true;
            return false;
        }
    }, {
        key: 'areArraysEqual',
        value: function areArraysEqual(arr1, arr2) {
            return arr1.sort().toString() == arr2.sort().toString();
        }
    }, {
        key: 'removeEmptyKeys',
        value: function removeEmptyKeys(pushDict) {
            var updated_dict = {};
            for (var key in pushDict) {
                var value = pushDict[key];
                if (this.isEmpty(value)) continue;else if (typeof value == "object") {
                    var updated_value = this.removeEmptyKeys(value);
                    if (this.isEmpty(updated_value)) continue;
                    updated_dict[key] = updated_value;
                } else {
                    updated_dict[key] = value;
                }
            }
            return updated_dict;
        }
    }, {
        key: 'sendPushNotification',
        value: function sendPushNotification() {
            var job_dict = this.pushNotification;
            job_dict = this.validate(job_dict);
            this.send(job_dict, this.queueName, 0);
        }
    }, {
        key: 'addHeaders',
        value: function addHeaders(input_object) {
            this.pushNotification.reference_id = input_object.reference_id;
            this.pushNotification.reference_type = input_object.reference_type;
            if ('is_silent' in input_object) this.pushNotification.is_silent = input_object.is_silent;
            if ('is_content_available' in input_object) this.pushNotification.is_content_available = input_object.is_content_available;
            if ('push_type' in input_object) this.pushNotification.push_type = input_object.push_type;
        }
    }, {
        key: 'addFilters',
        value: function addFilters(input_object) {
            if ('last_active' in input_object) this.pushNotification.last_active = input_object.last_active;
            if ('account_id' in input_object) this.pushNotification.account_id = input_object.account_id;
            if ('device_id' in input_object) this.pushNotification.device_id = input_object.device_id;
            if ('app_version' in input_object) this.pushNotification.app_version = input_object.app_version;
            if ('app_version_code' in input_object) this.pushNotification.app_version_code = input_object.app_version_code;
        }
    }, {
        key: 'addData',
        value: function addData(input_object) {
            if ('data' in input_object) Object.assign(this.pushNotification.data, input_object.data);
            if ('failure_reason' in input_object) Object.assign(this.pushNotification.failure_reason, input_object.failure_reason);
            if ('campaign_id' in input_object) Object.assign(this.pushNotification.campaign_id, input_object.campaign_id);
        }
    }, {
        key: 'preparePushBody',
        value: function preparePushBody(input_object) {
            this.addHeaders(input_object);
            this.addFilters(input_object);
            this.addData(input_object);
        }
    }, {
        key: 'validatePushType',
        value: function validatePushType(push_type) {
            throw new exceptions.PushNotImplementedException('Validate push type has not been implemented');
        }
    }, {
        key: 'validateFilters',
        value: function validateFilters(pushDict) {
            throw new exceptions.PushNotImplementedException('Validate filters has not been implemented');
        }
    }, {
        key: 'validatePushRelationKeys',
        value: function validatePushRelationKeys(pushDict) {
            for (var index = 0; index < this.push_relation_keys.length; index++) {
                var key = this.push_relation_keys[index];
                var value = pushDict[key] ? 'key' in pushDict : {};
                if (Object.keys(value).length !== 0) {
                    if (['value', 'relation'] !== Object.keys(value)) {
                        throw new exceptions.PushValidationException("Invalid keys in " + key);
                    }
                    if (this.push_relations.indexOf(value['relation']) < 0) {
                        throw new exceptions.PushValidationException("Invalid relation in " + key);
                    }
                }
            }
        }
    }, {
        key: 'validateMandatoryKeys',
        value: function validateMandatoryKeys(mandatory_keys, pushDict) {
            var missing_keys = Array.from(new Set(mandatory_keys) - new Set(Object.keys(pushDict)));
            if (missing_keys.length !== 0) throw new exceptions.PushValidationException("Missing Mandatory Keys " + missing_keys);
            for (var index = 0; index < mandatory_keys.length; index++) {
                var key = mandatory_keys[index];
                if (emptyValues.indexOf(pushDict[key]) >= 0) throw new exceptions.PushValidationException("Key " + key + " cannot be empty");
            }
        }
    }, {
        key: 'validateTypes',
        value: function validateTypes(pushDict) {
            var ptypes = new types.PushDataTypes();
            for (var key in ptypes.types) {
                var val = pushDict[key];
                if (val === undefined) {
                    continue;
                }
                if (emptyValues.indexOf(val) >= 0 || typeof val !== ptypes.types[key]) {
                    throw new exceptions.PushValidationException("Invalid Type for key " + key);
                }
            }
        }
    }, {
        key: 'validateAndroidData',
        value: function validateAndroidData(androidData) {
            if (emptyValues.indexOf(androidData) >= 0) throw new exceptions.PushValidationException("No Data in Android Payload");
        }
    }, {
        key: 'validateIosData',
        value: function validateIosData(iosData, isIosSilent, pushDict) {
            if (emptyValues.indexOf(iosData) >= 0) throw new exceptions.PushValidationException("No Data in Ios Payload");
            if (isIosSilent) {
                pushDict.is_content_available = true;
                if (!this.areArraysEqual(Object.keys(iosData), ['custom'])) {
                    throw new exceptions.PushValidationException("Silent Push can only have custom keys");
                }
            } else if (this.areArraysEqual(Object.keys(iosData), ['custom'])) {
                throw new exceptions.PushValidationException("Non Silent Push data cant be empty");
            }
        }
    }, {
        key: 'validateData',
        value: function validateData(pushDict) {
            if (pushDict.is_silent === undefined) throw new exceptions.PushValidationException("Is Silent value cannot be undefined");
            if ('android' === pushDict.app_name) this.validateAndroidData(pushDict.data);else if ('ios' === pushDict.app_name) this.validateIosData(pushDict.data, pushDict.is_silent, pushDict);
        }
    }, {
        key: 'validate',
        value: function validate(pushDict) {
            pushDict = this.removeEmptyKeys(pushDict);
            this.validateTypes(pushDict);
            this.validateMandatoryKeys(this.mandatory_keys, pushDict);
            this.validateFilters(pushDict);
            this.validateData(pushDict);
            this.validatePushType(pushDict.push_type);
            pushDict.app_name = this.comm_app_name;
            return pushDict;
        }
    }]);

    return BasePush;
}(base.Base);

module.exports = {
    BasePush: BasePush
};
